@@ -46,8 +46,6 @@ module Hledger.Data.Posting (
   postingDate,
   postingDate2,
   postingDateOrDate2,
-  isPostingInDateSpan,
-  isPostingInDateSpan',
   -- * account name operations
   accountNamesFromPostings,
   -- * comment/tag operations
@@ -87,17 +85,17 @@ where
 import Data.Default (def)
 import Data.Foldable (asum)
 import Data.Function ((&))
-import qualified Data.Map as M
+import Data.Map qualified as M
 import Data.Maybe (fromMaybe, isJust, mapMaybe)
 import Data.List (sort, union)
 #if !MIN_VERSION_base(4,20,0)
 import Data.List (foldl')
 #endif
-import qualified Data.Set as S
+import Data.Set qualified as S
 import Data.Text (Text)
-import qualified Data.Text as T
-import qualified Data.Text.Lazy as TL
-import qualified Data.Text.Lazy.Builder as TB
+import Data.Text qualified as T
+import Data.Text.Lazy qualified as TL
+import Data.Text.Lazy.Builder qualified as TB
 import Data.Time.Calendar (Day)
 import Safe (maximumBound)
 import Text.DocLayout (realLength)
@@ -107,7 +105,7 @@ import Hledger.Utils
 import Hledger.Data.Types
 import Hledger.Data.Amount
 import Hledger.Data.AccountName
-import Hledger.Data.Dates (nulldate, spanContainsDate)
+import Hledger.Data.Dates (nulldate)
 import Hledger.Data.Valuation
 
 
@@ -435,7 +433,7 @@ postingStatus Posting{pstatus=s, ptransaction=mt} = case s of
 postingAllTags :: Posting -> [Tag]
 postingAllTags p = ptags p ++ maybe [] ttags (ptransaction p)
 
--- | Tags for this transaction including any from its postings.
+-- | Tags for this transaction including any from its postings (which includes any from the postings' accounts).
 transactionAllTags :: Transaction -> [Tag]
 transactionAllTags t = ttags t ++ concatMap ptags (tpostings t)
 
@@ -444,15 +442,6 @@ relatedPostings :: Posting -> [Posting]
 relatedPostings p@Posting{ptransaction=Just t} = filter (/= p) $ tpostings t
 relatedPostings _ = []
 
--- | Does this posting fall within the given date span ?
-isPostingInDateSpan :: DateSpan -> Posting -> Bool
-isPostingInDateSpan = isPostingInDateSpan' PrimaryDate
-
--- --date2-sensitive version, separate for now to avoid disturbing multiBalanceReport.
-isPostingInDateSpan' :: WhichDate -> DateSpan -> Posting -> Bool
-isPostingInDateSpan' PrimaryDate   s = spanContainsDate s . postingDate
-isPostingInDateSpan' SecondaryDate s = spanContainsDate s . postingDate2
-
 isEmptyPosting :: Posting -> Bool
 isEmptyPosting = mixedAmountLooksZero . pamount
 
